#
# spec file for package claws-mail
#
# Copyright (c) 2012 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           claws-mail
Version:        3.7.8
Release:        11.1
Url:            http://www.claws-mail.org/
Summary:        A lightweight and highly configurable email client
License:        GPL-3.0+
Group:          Productivity/Networking/Email/Clients
Source0:        http://prdownloads.sourceforge.net/sylpheed-claws/%{name}-%{version}.tar.bz2
Patch0:         claws-mail-python.diff
Patch1:         claws-mail-desktop.diff
# PATCH-FIX-UPSTREAM claws-mail-3.8.1-procmime-vuln.patch bnc#784463 -- NULL pointer derefence while processing email content. 
Patch2:         claws-mail-3.8.1-procmime-vuln.patch
BuildRequires:  NetworkManager-devel
BuildRequires:  compface
BuildRequires:  db-devel
BuildRequires:  docbook-utils
BuildRequires:  enchant-devel
BuildRequires:  fdupes
BuildRequires:  gettext
BuildRequires:  gmp-devel
BuildRequires:  gnutls-devel
BuildRequires:  gpgme-devel
BuildRequires:  gtk2-devel
BuildRequires:  libetpan-devel >= 0.57
BuildRequires:  openldap2-devel
BuildRequires:  pilot-link-devel
BuildRequires:  pkgconfig
BuildRequires:  startup-notification-devel
BuildRequires:  update-desktop-files
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Requires:       pinentry-gtk2
Recommends:     %{name}-lang
Provides:       sylpheed-claws = %{version}
Obsoletes:      sylpheed-claws < %{version}

%description
Claws Mail (previously known as Sylpheed-Claws) is a lightweight and
highly configurable email client and news reader based on the GTK+ GUI
toolkit, it runs on the X Window System.

Claws Mail is free software distributed under the GNU GPL.

To run Claws Mail use 'claws-mail' on the command line.

When claws-mail is executed for the first time a configuration 'Wizard'
will appear prompting you for the minimum information necessary to
create a new account.

%package devel
Summary:        A lightweight and highly configurable email client
License:        GPL-2.0+
Group:          Development/Libraries/Other
Provides:       claws-mail:/usr/include/claws-mail/main.h
Requires:       claws-mail = %{version}
Requires:       enchant-devel
Requires:       glib2-devel
Requires:       gnutls-devel
Requires:       gpgme-devel
Requires:       gtk2-devel
Requires:       libetpan-devel
Requires:       openldap2-devel

%description devel
Claws Mail (previously known as Sylpheed-Claws) is a lightweight and
highly configurable email client and news reader based on the GTK+ GUI
toolkit, it runs on the X Window System.

Claws Mail is free software distributed under the GNU GPL.

To run Claws Mail use 'claws-mail' on the command line.

When claws-mail is executed for the first time a configuration 'Wizard'
will appear prompting you for the minimum information necessary to
create a new account.

%lang_package
%prep
%setup -q
%patch0
%patch1 -p1
%patch2 -p1

%build
%configure \
        --docdir=%{_datadir}/claws-mail \
        --disable-static \
        --enable-ldap \
        --enable-ipv6 \
        --enable-openssl \
        --enable-jpilot \
        --enable-spamassassin-plugin \
        --enable-dillo-viewer-plugin \
        --enable-trayicon-plugin \
        --enable-pgpcore-plugin \
        --enable-pgpmime-plugin \
        --enable-pgpinline-plugin \
        --disable-demo-plugin \
        --enable-crash-dialog \
        --enable-startup-notification \
        --enable-compface \
        --enable-libetpan
%__make %{?jobs:-j%jobs}

%install
%makeinstall
# Clean up
%__rm %{buildroot}%{_libdir}/claws-mail/plugins/*.la
# install desktop file
%suse_update_desktop_file -G "Email client" claws-mail
# we want to have the icon installed in /usr/share/pixmaps
%__mkdir_p %{buildroot}%{_datadir}/pixmaps/
%__cp claws-mail-64x64.png %{buildroot}%{_datadir}/pixmaps/
# Tools
%__cp -r tools %{buildroot}%{_datadir}/%{name}
%__rm %{buildroot}%{_datadir}/claws-mail/tools/Makefile*
%__mv %{buildroot}%{_datadir}/claws-mail/tools/README ./README.tools
# fixing permissions
%__chmod 755 %{buildroot}%{_datadir}/claws-mail/tools/*
%__chmod 644 %{buildroot}%{_datadir}/claws-mail/tools/multiwebsearch.conf
%__chmod 644 %{buildroot}%{_datadir}/claws-mail/tools/ca-certificates.crt
%find_lang %{name} %{?no_lang_C}
%fdupes %{buildroot}%{_libdir}/%{name}/plugins/
%__install -d %{buildroot}%{_sysconfdir}/skel/.claws-mail/
cat <<EOF > %{buildroot}%{_sysconfdir}/skel/.claws-mail/clawsrc
[Plugins_GTK2]
%{_libdir}/claws-mail/plugins/pgpcore.so
%{_libdir}/claws-mail/plugins/pgpinline.so
%{_libdir}/claws-mail/plugins/pgpmime.so
%{_libdir}/claws-mail/plugins/smime.so
EOF

%clean
%__rm -rf %{buildroot}

%if 0%{?suse_version} > 1130

%post
%desktop_database_post
%icon_theme_cache_post
%endif

%if 0%{?suse_version} > 1130

%postun
%desktop_database_postun
%icon_theme_cache_postun
%endif

%files
%defattr(-,root,root)
%doc AUTHORS COPYING ChangeLog NEWS README README.tools TODO
%{_bindir}/claws-mail
%{_bindir}/sylpheed-claws
%dir %{_libdir}/claws-mail
%dir %{_libdir}/claws-mail/plugins
%{_libdir}/claws-mail/plugins/*.so
%{_libdir}/claws-mail/plugins/*.deps
%{_datadir}/applications/claws-mail.desktop
%{_datadir}/icons/hicolor/*/apps/claws-mail.png
%{_datadir}/pixmaps/claws-mail-64x64.png
%dir %{_datadir}/claws-mail
%doc %{_datadir}/claws-mail/RELEASE_NOTES
%doc %{_datadir}/claws-mail/manual/
%dir %{_datadir}/claws-mail/tools
%{_datadir}/claws-mail/tools/*.sh
%{_datadir}/claws-mail/tools/*.pl
%{_datadir}/claws-mail/tools/*.py
%{_datadir}/claws-mail/tools/*.conf
%{_datadir}/claws-mail/tools/ca-certificates.crt
%{_datadir}/claws-mail/tools/tb2claws-mail
%{_datadir}/claws-mail/tools/u*
%{_datadir}/claws-mail/tools/kdeservicemenu/
%{_mandir}/man1/claws-mail.1.gz
%config(noreplace) %{_sysconfdir}/skel/.claws-mail/

%files devel
%defattr(-,root,root)
%{_includedir}/claws-mail/
%{_libdir}/pkgconfig/claws-mail.pc

%files lang -f %{name}.lang

%changelog
* Fri Oct 12 2012 zaitor@opensuse.org
- Add claws-mail-3.8.1-procmime-vuln.patch: Fixes NULL pointer
  derefence while processing email content. (bnc#784463),
  (CVE-2012-4507).
* Sat Feb 12 2011 vuntz@opensuse.org
- Stop removing themed icons: we want them!
- Add missing relevant macros in %%post/%%postun:
  + %%icon_theme_cache_post/postun because the package ships themed
    icons.
- Pass %%{?no_lang_C} to %%find_lang so that english documentation
  can be packaged with the program, and not in the lang subpackage.
- Change Requires of lang subpackage to Recommends, since the
  english documentation is not there anymore.
* Wed Jan 26 2011 gber@opensuse.org
- Update claws-mail-desktop.diff so Claws can be used as the
  default mailto uri handler (by declaring it handles
  x-scheme-handler/mailto).
- Call %%desktop_database_post/%%desktop_database_postun in
  %%post/%%postun.
* Wed Dec 29 2010 mrueckert@suse.de
- added /etc/skel/.claws-mail/clawsrc:
  In a good default config we want to enable pgp/smime support by
  default. Claws-mail will pick up that file when creating a new
  ~/.claws-mail directory, so this even works for existing users,
  who want to try out claws-mail.
  http://www.thewildbeast.co.uk/claws-mail/bugzilla/show_bug.cgi?id=2335
* Wed Dec  8 2010 vuntz@opensuse.org
- Update to version 3.7.8:
  + Bug fixes:
  - Shortcuts should not be modifiable by default
  - CLI quicksearch sometimes returns the same messages twice
  - Action results in "Bad file descriptor"
  - NNTP: fix replying (broken in corner case)
  - Please re-introduce quick shortcut for marking as spam
  + Build fixes.
* Wed Dec  8 2010 vuntz@opensuse.org
- Add docbook-utils BuildRequires to build the manuals.
* Sat Nov 20 2010 nmo.marques@gmail.com
- Update to version 3.7.7:
  + Enable building with GTK+ 2.22.
  + A QuickSearch can now be run from the command line using the
  - -search command. See `claws-mail --help` for more information.
  + Added a hidden option to set a margin in the text area of the
    Compose window. 'show_compose_margin', defaults to FALSE.
  + QuickSearch: Do not add rules with bad syntax to history
  + Hide progressbar on statusbar when not needed
  + Fix multiple @ in generated message-ids, prohibited in RFC
    2822.
  + UMPCs: Fix truncated text in progressbar and statusbar
  + Bug fixes:
  - Cannot send mail when SSL certificate is expired but
    certificate check is skipped
  - Changing NNTP account's SSL setting requires restart
  - disable double-click quote collapsing
  - SSL is not working with POP3
  - PGPInline: segfault on malformed mails
  - LDAP encrypted passwords produce invalid XML
  - in some cases, button to clean quick search has no icon
  - freeze when using quick search
  - Empty trash on exit fails on scripted exit
  - base64 decoding fails with line breaks
  - nntp reply-to-all broken?
  - Colors not index correctly
  - Segfault when loading inbox for the first time
  - filtering: simplify expression
  - addrindex.c: address index conversion always fails
  + Build fixes.
  + Updated manual and man page.
  + Updated translations.
- Version Provides/Obsoletes of sylpheed-claws (to avoid
  self-obsoletion).
- Use Development/Libraries/Other group for devel subpackage
  instead of Productivity/Networking/Email/Clients.
- Add fdupes BuildRequires, and use fdupes.
- Update claws-mail-desktop.diff to remove Info field, and to not
  remove the GTK category.
* Mon Jun 21 2010 dimstar@opensuse.org
- Update to version 3.7.6:
  + Require GTK+ 2.10 or newer
  + Enable building with GTK+ 2.19 or newer
  + Enable building with libetpan 1.0
  + Encrypt saved LDAP passwords
  + Filtering/Processing: Added 'List-Id' to the pre-defined
    headers
  + Added 'Reply to this address' to popup menu in the Message View
  + Added separate search phrase completion for normal/extended
    QuickSearch
  + Several interface improvements
  + Use in-reply-to info that is passed in mailto: links
  + Added the GB18030 Chinese charset, which is a superset of
    GB2312 and (X-)GBK.
  + Updated translations.
* Wed Feb 10 2010 dimstar@opensuse.org
- Update to version 3.7.5:
  + gpgme >= 1.1.8 not compatible with S/MIME encryption
  + having worked 2 times properly CLAWS ceased to decrypt incoming
    PGP mails, displas base64 instead.
  + claws-mails crashes frequently with pgpcore
  + Address book: fix button sensitivity in compose mode.
* Mon Jan 11 2010 dimstar@opensuse.org
- Update to version 3.7.4:
  + Spell checker: Highlight misspelled words when applying
    template and 'check while typing' option is on
  + Spell checker: Highlight misspelled words in text inserted from
    file(s) or pasted to message body when 'check while typing'
    option is on
  + Improve parsing of List-Post header
  + Add new drag type "claws-mail/msg-path-list" for drag'n'drop of
    a message selection from the message list into other
    applications. This enables other applications to back-link to
    Claws Mail via a "claws-mail --select" call after they received
    a drop.
  + Place the cursor in the compose window according to provided
    input. If To: is present place cursor in Subject: field and if
    both To: and Subject: are present place cursor in body. If
    body: is present insert a new line after text and place cursor
    there.
  + QuickSearch: Use all of the available space to view expressions
* Mon Nov 30 2009 dimstar@opensuse.org
- Update to version 3.7.3:
  + Bug 1994 - Changing colors required restart
  + Bug 2003 - Address gathering dialog minor bugs/annoyances
  + enable Page Size and Orientation in the print dialog
  + Bug 2008 - Claws-Mail doesn't refresh after deletion
  + Bug 2009 - Incorrect pointer representation with GTK+2.18
  + Bug 2007 - Small memory leaks
  + Bug 2006 - Non-utf8 strftime(3) date strings shows garbled
  + Bug 1997 - Add 'has_attachment' and 'signed' matcher expression
  + Bug 1999 - Add "Re :" prefix from french Yahoo mail
  + rh#512024 - folder.c:3543  Condition msglist != NULL failed
  + Bug 1986 - New feature: warn user when inserting a large file
    in the message body
  + Bug 1984 - Add Ref. : reply prefix
  + Bug 1969 - Bad guess for outgoing encoding
  + Bug 1950 - Program freeze up during folder selection
  + Bug 1957 - LDAP errs out after searching too many search bases
  + Bug 1966 - "Collapse all threads" slower than "Expand all
    threads"
  + Bug 1967 - Claws gets stuck after accepting a certificate
    warning dialog
  + Bug 1954 - Segfault on reading wrong STATUS
* Wed Aug  5 2009 dominique-obs@leuenberger.net
- Update to version 3.7.2:
  + Too many changes to be listed since version 3.5.0.
    For more details, please see NEWS.
- Add --disable-static to configure, thus no need to delete *.a.
- Removed obsoleted configure parameters --enable-aspell,
  - -enable-clamav-plugin and --disable-mathml-viewer-plugin
- Drop claws-mail-compilefixes.diff, as it's been upstreamed,
  remove suse_update_config and autoreconf call.
- Remove all if's for obsoleted {open}SUSE versions.
- Remove make check. Does no longer exist.
- Remove BuildRequires: curl-devel (not needed), libbz2-devel (not
  needed), pcre-devel (not needed), libgnomeprint{ui}-devel
  (deprecated).
- Replace aspell-devel with enchant-devel.
- Due to licensing issues, openssl support was replaced by gnutls
  support (replace openssl-devel by gnutls-devel BuildRequires).
- Split lang package.
- Add missing Provides for sylpheed-claws (earlier name of the
  package).
- Fix Requires of devel package.
- Remove custom LDFLAGS and CFLAGS.
* Fri Jul 17 2009 coolo@novell.com
- compile with LFS to fix build
* Sun Jun 21 2009 coolo@novell.com
- Update claws-mail-compilefixes.diff to fix build with automake
  1.11
* Thu Oct 23 2008 puzel@suse.cz
- requires pinentry-gtk2 (bnc#394569)
* Mon Oct 13 2008 nadvornik@suse.cz
- fixed gtk includes
* Thu Jul 10 2008 anosek@suse.de
- synced with BS, reviewed changes made by suse-tux
* Mon Jun 30 2008 suse-tux@gmx.de
- new upstream version 3.5.0
  [#] Added an option, "Use secure file deletion if possible"
  [#] Added an option, "Select the HTML part of multipart/alternative
    messages".
  [#] Added an option to the 'Create new folder' dialogue which enables
    new folders to inherit the properties of their parent folders
    during folder creation.
  [#] Added a hidden option, "two_line_vertical"
  [#] Added a hidden option, "outgoing_fallback_to_ascii"
  [#] Added support for the Avant Window Navgator (Awn) information
    bubble. This is automatically enabled if dbus is available.
  [#] Face and X-Face headers can now be added globally and per-account
    from configuration files under ~/.claws-mail/autofaces/. Further
    information is provided in the manual.
  [#] The SHA1 fingerprint is now shown on the SSL certificate dialogue
    and the labels are now selectable.
  [#] tools/csv2addressbook.pl
    Support for a gmail exported csv address book was added.
* Sun Apr 27 2008 suse-tux@gmx.de
- new upstream version 3.4.0:
  [#] Added support for /dev/mem_notify. This Linux kernel feature
    will allow applications to be notified that memory has to be
    freed before getting OOM-killed.
    For more information: http://lwn.net/Articles/267013/
  [#] Enabled moving/copying folders to root folders when using the
    folder selection dialogue.
  [#] Global and per-folder templates can now override the From name.
  [#] Added a tooltip with extended folder stats. (Hover the cursor over
    the short stats on the right, below the message list.)
  [#] Implemented 2-line items in the message list when in three column
    mode.
  [#] Added support for png themes.
  [#] Added an icon for attached patches (text/x-patch and text/x-diff).
  [#] When viewing a message that has a large amount of text, show a
    maximum of 1MB of text and add a noticeview to show optionally show
    the whole message.
  [#] Added a button to the templates preferences to restore defaults for
    current language.
  [#] Added search in filtering rules list.
  [#] Bogofilter Plugin:
    added a "learn from whitelist" preference.
  [#] MAEMO:
    Added information when fetching large messages.
  [#] tools/csv2addressbook.pl
    Added support for Kmail/Kaddressbook.
  [#] Updated translations: Brazilian Portuguese, Finnish, French,
    German, and Italian.
  [#] and several bugfixes
- added "BuildRequires: pcre-devel" to build against openSUSE_10.3:Update
* Thu Mar  6 2008 suse-tux@gmx.de
- fixed Requires in the devel package (again) - now it should build
  in factory
* Wed Feb 27 2008 anosek@suse.cz
- updated to version 3.3.1, update is based on package from BS
  * Forbid attaching anything containing "../" or ".ssh/" in mailto:
    URIs.
  * Add a hidden preference, 'use_networkmanager', to disable
    NetworkManager handling
  * Due to licensing problems, the ClamAV plugin has been removed
  * Added NetworkManager support
  * Added DIGEST-MD5 support for IMAP authentication
  * Added Folder Properties option, 'Run processing rules when opening'
    to the General page.
  * Added sub-sorting to the Message List; when the Sort type is either
    Subject, From, To or Tags, sub-sorting by Date will be active.
  * Added from=address to the mailto sequence
    The 'from' will try to select the first matching account in the
    Accounts list, otherwise it will use the usual account selection
    mechanism but will override it with the given 'from' address.
  * Added insert=FILE  to the mailto sequence (stands for 'insert file')
    This adds the ability to create a new message from the command-line,
    with the body set from the contents of an existing file.
  * Added mailto with NNTP accounts
    This comes into play if mailto is used when an NNTP account is the
    default account or if an NNTP account address is used with 'from'.
  * Added several GUI improvements to the Filtering, Processing, Tags,
    Actions, Templates, Logging and Address Book dialogues
  * Added a tooltip to the 'replied' icon in the Message List which
    indicates 'click to see your reply' feature.
  * Added 'claws-mail --version-full' to display the version and a list
    of the compiled-in features
  * Implemented speed-ups to list operations, deletions and cache
    updates.
  * Updated the man page
  * The Trayicon plugin icons are now themable.
  * text/calendar message parts are now automatically displayed if a
    plugin handling text/calendar is loaded, e.g. vCalendar.
  * Maemo: connect HW status change signal for shutdown
  * Maemo: identify mmc1 and mmc2 more clearly in the GUI
* Thu Dec 20 2007 anosek@suse.cz
- updated to version 3.2.0
  - lots of improvements and bugfixes from version 2.10.0,
    please, see NEWS file
* Thu Oct 11 2007 sbrabec@suse.cz
- Removed bogus dependency on mDNSResponder.
* Thu Aug 23 2007 anosek@suse.cz
- dropped not needed BuildRequires: librsaref2
* Wed Jul 25 2007 anosek@suse.cz
- enabled Patch2 (claws-mail-desktop.diff) again, it's needed for
  abuild
- added BuildRequires: librsaref2
* Wed Jul  4 2007 suse-tux@gmx.de
- updated to version 2.10.0
  [#] Bug fixes:
    o bug 848, 'Redirect breaks GnuPG'
    o bug 1217, 'reentrancy problems with time functions'
    o bug 1248, 'Core dumps after unloading plugin and clicking
    on load plugins'
    o bug 1249, 'Error handling for news errors needs
    modification'
    o Race condition when automatically drafting due to
    insertion on re-edit.
    o Consider "- -- \n" as signature separator (fixes signature
    stripping when replying to PGP/Inline signed emails).
    o Race condition crash when reconnection fails on IMAP.
    o Raising log windows when they are either minimized or in
    background.
    o Occasional crasher when cancelling message sending.
    o Stale news statusbar when scanning fails.
    o A few race conditions when sending/drafting emails.
    o Building of some plugins in Mac OS X.
    o Don't decode leading ENV_ and ~ in P_PASSWORD configuration
    values.
    o Incoming messages from local accounts always get filtered
    regardless of the preference.
    o Use gethostname() instead of uname(), fixes failures to
    determine hostname on some BSDs.
    o Crash if fork() fails when resolving hostnames.
    o Infinite loop when exiting with compose window(s) opened,
    when the draft folder is on IMAP and unreachable.
    o Sizing/alignment of the button bar in plugins window.
    o Copying text from HTML parts.
    o 'make distcheck' failure
- disabled Patch4 (claws-mail-openldap.diff) - this shouldn't be needed
  anymore.
- disabled Patch2 (claws-mail-desktop.diff) - this isn't needed anymore.
* Wed Jun  6 2007 anosek@suse.cz
- updated to version 2.9.2
  [#] Added a printer icon.
  [#] Bug fixes
    o bug 1187, 'Reply-to addressee disappears when reply-to text
    box is clicked...' (Maemo)
    o bug 1190, 'dir_open' button doesn't work' (Maemo)
    o bug 1193, 'Need a way to multi-select items'
    o bug 1194, 'Hardware keys move from email list to account/
    directory list, but not back to email list...'
    o bug 1196, 'Edit>Select All doesn't work' (Maemo)
    o bug 1198, 'Reply-all "disappearing" address bug
    persists...'
    o bug 1200, 'Add option to always retrieve full messages'
    o bug 1209, 'Clicking on address in header (mailto uri)
    selects default account'
    o bug 1211, 'Offline dialog message bugs/annoyances...'
    o Don't reflect accounts changes to the mainwindow when it's
    not necessary.
    o Fix double fetching of mails if first try failed
    o Fix a crash in textview
    o Fix changing quicksearch type (after Esc, after changing
    Recursive, ...)
    o tools/uudec Fix missing dash to `display` command-line
* Thu May 24 2007 ro@suse.de
- split off devel package
* Mon May  7 2007 anosek@suse.cz
- updated to version 2.9.1
  [#] Security fix:
    o Fix for CVE-2007-1558 (APOP)
    http://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2007-1558
  [#] Bug fixes
    o Fix bug 1185, 'Pluginwindow's [X] button doesn't save'
    o Fix encoding woes wrt saving of mails and parts
* Mon Jan 29 2007 anosek@suse.cz
- updated to version 2.7.2
  * Attaching files from 'mailto:' URIs (&attach=...) is now
    possible. A dialog is displayed to make sure that the user is
    aware that the mail will contain attachments
  * 'New Message format' has been added to the Compose/Writing
    options, this works like the Quote format and the same symbols
    are supported
  * Reworked the About dialog, including the addition
    of a new page, 'Features', which indicates which
    of the optional features are compiled in and which are not.
    A 'Release Notes' page was also added
  * Added history combo for all search fields (message and text)
  * The 'mark_as_read_delay' option is not hidden anymore and can
    be found in Configuration/Preferences/Summaries
  * Added global and per-folder preferences to set the default
    alternate dictionary
  * Allow spell-checking to use both current and alternate
    dictionaries
  * Added an hidden option 'addressbook_use_editaddress_dialog' to
    embed the contact editor in the addressbook window in contrast
    to a separate dialog
  * Added a hidden option 'unsafe_ssl_certs', to allow storing
    multiple SSL certificates for a given server/port. You will be
    asked to accept unknown certificates. Unchecking this option
    will require you to re-accept previously known certificates
  * Allow copying of folders between mailboxes
  * Better automatic account selection for mailing lists (searches
    for the email address in the Delivered-To header also)
  * Made the "Synchronise" menu item inactive when there's
    nothing to synchronise
  * Use Message font in Writing and Quoting preferences,
    as well as in Templates
  * and much more new features ...
* Thu Dec  7 2006 anosek@suse.cz
- udpated to version 2.6.1
  * Sylpheed-Claws is now known as Claws Mail. The default
    configuration directory is now ~/.claws-mail. The main
    configuration file is now called 'clawsrc'.
  * Several bugfixes
- enabled spamassassin plugin again
* Thu Oct 12 2006 anosek@suse.cz
- updated to version 2.5.5
  * Bug fixes:
    o bug 1034, 'Incorrect display of size field in message view'
    o bug 1032, 'Segmentation fault when showing message'
    o fix crash with quote folding on HTML
    o fix building with --disable-nls
  * remove tabs in Subject string
- resolved license problems [#210169]
  * disabled spamassassin plugin
  * removed GurUnix Theme completely
* Wed Oct 11 2006 anosek@suse.cz
- updated to version 2.5.3
  * Make node expanding in the Folder List non-recursive
  * Bug fixes:
    o Fix "Check for new folders" on folders with accented
    characters
    o Fix filtering "copy" rules
    o Fix "goto next unread" after collapsing/expanding a node
- moved extra-plugins into separate spec file
- spec files are now based on versions from BuildService
  by Marcus Huewe <marcus@links2linux.de>
* Wed Sep 27 2006 anosek@suse.cz
- updated to version 2.5.2
  * New plugin: Bogofilter, providing Spam filtering and learning
  * Account-based filtering rules. Each filtering rule can now be
    assigned to a specific account, by default it's "All".
  * Filtering against Address Book. It is now possible add matched
    conditions to determine if any email address in a message
    matches or doesn't match any or all books or folders
    in the Address Book.
  * Quote folding. Quotes in the message view can now be folded,
    via the "/View/Quotes/..." menu. The folding can also be
    toggled by double clicking on the quotes in the Message View
  * "/View/Go to/Parent message" and "/View/Go to/Last read
    message" have been added
  * IMAP: Added a View Log button on auth error
  * PGP/Core plugin: it is now possible to create a new key pair
    from within Sylpheed-Claws
  * PGP/Core plugin: When encrypting, if only one key matches,
    and it matches exactly, it is automatically used
  * Enabled text selection for replying from MimeViewer plugins
  * And more ...
- small fixes (prototypes.patch) (warnings.patch)
- created new package sylpheed-claws-extra-plugins
* Thu Sep 21 2006 zpetrova@suse.cz
- version upgrade to 2.4.0
  - major rewrites all over the place
  - port to gtk2
  - many bugfixes
* Sun Sep 17 2006 ro@suse.de
- fix missing return value
* Tue Jun 20 2006 dmueller@suse.de
- build parallel
* Wed Feb 15 2006 ro@suse.de
- added curl-devel to BuildRequires
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Tue Jan 24 2006 zpetrova@suse.cz
- another build problem appeared, fixed.
* Wed Jan 18 2006 zpetrova@suse.cz
- fixed built
* Sat Jan 14 2006 kukuk@suse.de
- Add gpgme-devel to nfb
* Sat Jan 14 2006 kukuk@suse.de
- Add gmp-devel to nfb
* Wed Nov 16 2005 zpetrova@suse.cz
- fix several buffer overflows: (#132688, #72801)
* Thu Sep 29 2005 zpetrova@suse.cz
- Add LDAP_DEPRECATE macro to compile with new openldap.
  (temporary workaround)
* Mon Sep 26 2005 zpetrova@suse.cz
- fix some gcc4.1 warnings
* Tue May  3 2005 ro@suse.de
- fix some gcc4 warnings
* Tue Mar 22 2005 mmj@suse.de
- Update to 1.0.3 [#72801]
* Sat Feb 19 2005 ro@suse.de
- use -fno-strict-aliasing until code has been cleaned up
* Thu Feb 17 2005 didge@suse.de
- version 1.0.1
- maildir plugin 0.7
- new iconset 20040929
* Mon Oct 25 2004 didge@suse.de
- version 0.9.12b
- ghostscript-viwer 0.8
- disabled new pgpmime plugin as gpgme-support is still missing
* Tue Aug 24 2004 didge@suse.de
- enabled clamav plugin
* Fri Aug  6 2004 didge@suse.de
- renamed to sylpheed-claws
* Thu Aug  5 2004 didge@suse.de
- version 0.9.12
- name paths is now sylpheed-claws
- ghostscript-viwer 0.7
- added maildir plugin 0.6
* Wed Aug  4 2004 ro@suse.de
- recode desktop file to utf-8
* Mon Jul 26 2004 didge@suse.de
- disabled gpgme because of incompatibility with it's new API
* Mon Jun  7 2004 didge@suse.de
- version 0.9.11
- new iconset 20040525
* Fri Apr 23 2004 didge@suse.de
- fixed compiler warnings
* Sat Mar 20 2004 adrian@suse.de
- fix build, adding resmgr to neededforbuild
* Tue Mar  9 2004 didge@suse.de
- version 0.9.10
* Tue Feb 10 2004 didge@suse.de
- version 0.9.9
- new iconset 20040206
- fixed rights of the themes
* Fri Dec 19 2003 didge@suse.de
- version 0.9.8
* Mon Dec 15 2003 didge@suse.de
- added patch for a more secure exit/kill of sylpheed
- removed trayicon plugin
* Wed Dec 10 2003 didge@suse.de
- fixed lib path to work on 64bit
* Tue Dec  9 2003 didge@suse.de
- added some bugfixes that came after 0.9.7
* Thu Nov 27 2003 didge@suse.de
- version 0.9.7
- iconset 20031130
- ghostscript-viewer 0.6
* Thu Oct 16 2003 didge@suse.de
- added patch to fix alertpanel bug
* Mon Oct 13 2003 ro@suse.de
- fix python require
* Tue Oct  7 2003 didge@suse.de
- version 0.9.6
* Mon Sep 15 2003 didge@suse.de
- added theme Skypilot
* Tue Sep  2 2003 didge@suse.de
- diff from cvs added for some bugfixes
- workaround for 'aclocal -I ac' export
* Wed Aug 20 2003 sbrabec@suse.cz
- Removed obsolete libgtop from neededforbuild.
* Tue Aug 19 2003 ro@suse.de
- fixed lib64 problem
* Mon Aug 18 2003 didge@suse.de
- 2 more themes
- diff from cvs added for some bugfixes
* Tue Aug 12 2003 adrian@suse.de
- package desktop file
* Tue Aug 12 2003 adrian@suse.de
- install desktop file according to XDG
* Mon Aug  4 2003 didge@suse.de
- new version 0.9.4claws
- reactivated trayicon plugin
* Tue Jul 29 2003 ro@suse.de
- added readline-devel to neededforbuild
* Fri Jul 18 2003 didge@suse.de
- added patch against current CVS to fix some bugs
- removed trayicon plugin, because unload crashs sylpheed
- moved the README of the tools to %%doc
* Tue Jul 15 2003 sbrabec@suse.cz
- GNOME prefix change to /opt/gnome.
* Mon Jul 14 2003 didge@suse.de
- Version 0.9.3claws
- new Iconset
- ghostview-plugin added
* Thu Jul  3 2003 ro@suse.de
- install gnome files to /opt/gnome
* Tue Jul  1 2003 didge@suse.de
- updated files section
- added the tools for sylpheed
- added Gnome icon
* Mon Jun 23 2003 didge@suse.de
- Version 0.9.0claws
* Sat Jun 14 2003 coolo@suse.de
- package directories
* Tue Jun  3 2003 coolo@suse.de
- use BuildRoot
- fix file list to include tons of unpackages themes (to be reviewed)
* Wed May 14 2003 sf@suse.de
- corrected patch and use 'autoreconf -f -i'
* Tue Apr  1 2003 sf@suse.de
- actualize libtool (to be able to link libcompface.a into shlib)
* Mon Mar 31 2003 didge@suse.de
- Version 0.8.11claws
* Tue Mar 11 2003 didge@suse.de
- some more bugfixes from CVS
- current manual added
- updated translations
* Mon Mar 10 2003 kukuk@suse.de
- Set libdir
* Mon Mar  3 2003 didge@suse.de
- 2 more bugfixes and fixes of warnings from CVS
* Fri Feb 28 2003 didge@suse.de
- more patches from CVS
- updated KDE2/3 menu and icons
* Mon Feb 24 2003 didge@suse.de
- added the spamassassin plugins to the files section
- more patches from CVS
- removed md5 patch
* Mon Feb 17 2003 didge@suse.de
- added patch for some fixes and speedups from after 0.8.10claws
* Thu Feb 13 2003 didge@suse.de
- Version 0.8.10claws
- cut patch as most is in 0.8.10claws now
* Fri Jan 31 2003 didge@suse.de
- Version 0.8.9claws
- Fixed Bug 23266: remove -mminimal-toc from RPM_OPT_FLAGS
- Fixed Bug 23265 - sylpheed compile error in md5.c
* Thu Jan 30 2003 ro@suse.de
- use cyrus-sasl2 in neededforbuild
* Fri Jan 10 2003 didge@suse.de
- Version 0.8.8claws
- new Iconset (0.8.7claws)
* Mon Dec  2 2002 didge@suse.de
- Version 0.8.6claws
* Mon Oct 21 2002 didge@suse.de
- Version 0.8.5claws
- new Iconset
- patch against a bug
* Fri Sep 27 2002 ro@suse.de
- Added alsa alsa-devel to neededforbuild (esound)
* Wed Jul 31 2002 didge@suse.de
- Version 0.8.1claws
- Themes pack 3 added
* Thu Jul  4 2002 ro@suse.de
- added heimdal-devel to neededforbuild to make libtool happy
* Sat Jun 29 2002 olh@suse.de
- build with -mminimal-toc on ppc64
* Fri Jun 21 2002 didge@suse.de
- Version 0.7.8claws
* Fri May 10 2002 didge@suse.de
- Version 0.7.5claws
- Themes pack added
* Tue May  7 2002 ro@suse.de
- fixed specfile: no macro allowed in Version: line
* Tue Mar 12 2002 didge@suse.de
- Version 0.7.4claws
- many new features
* Thu Feb 28 2002 didge@suse.de
- added patch against CVS to fix segfault on opening a mime part
- added support for ISO-8859-15
- updated german translation
* Tue Feb 26 2002 didge@suse.de
- added patch against CVS to fix memory leak while handling attachments
* Mon Feb 25 2002 didge@suse.de
- Version 0.7.2claws
* Thu Feb 14 2002 didge@suse.de
- Version 0.7.1claws
* Wed Jan 16 2002 didge@suse.de
- Version 0.7.0claws
* Mon Dec 17 2001 didge@suse.de
- Version 0.6.6claws
- came back to normal releases, no cvs anymore
- the Santa Claws release :-)
* Mon Nov 26 2001 didge@suse.de
- a big bug is fixed (forgeting about read messages and marking
  them as unread again)
- my undo-patch is added
* Fri Nov 23 2001 didge@suse.de
- Bug with GPG is fixed
* Wed Nov 21 2001 didge@suse.de
- Version 0.6.5
- bugfix in spec
* Tue Nov 20 2001 ro@suse.de
- added cyrus-sasl-devel to neededforbuild
* Mon Oct 29 2001 didge@suse.de
- Version 0.6.4claws13
- de translations
* Mon Oct 22 2001 didge@suse.de
- Version 0.6.4claws1
* Tue Oct  9 2001 didge@suse.de
- Version 0.6.3claws2
* Mon Oct  1 2001 didge@suse.de
- Version 0.6.2claws12
- Pspell now works fine
* Fri Sep 28 2001 didge@suse.de
- Version 0.6.2claws
- Pspell deactivated because of segfault with SuSE, but will come soon
- current german translations
* Tue Sep  4 2001 didge@suse.de
- added missing translations
* Mon Sep  3 2001 didge@suse.de
- Version 0.6.1claws out of CVS
- German translations
- Some new features
* Thu Aug 23 2001 didge@suse.de
- Version 0.5.3claws3 out of CVS
- German translations
* Wed Aug 22 2001 didge@suse.de
- Version 0.5.3claws2 out of CVS
- GPGME exclude to an extra package
* Mon Aug  6 2001 didge@suse.de
- Version 0.5.2claws1 out of CVS
- ssl is working for IMAP and SMTP
* Tue Jul 31 2001 didge@suse.de
- Version 0.5.1claws3 out of the CVS
- gpgme compiled in the package (should better be an extra package)
- compiled with ipv6-support
- compiled with JPilot-support
- compiled with ldap-support
- compiled with ssl-support (not sure if working already)
- added tools in /usr/share/doc/packages/sylpheed
* Thu Jul 12 2001 didge@suse.de
- Version 0.5.0claws out of the CVS
* Thu Jun 28 2001 didge@suse.de
- Removes openldap requirement, to build on S390
  it was never used anyway
* Tue Jun 19 2001 didge@suse.de
- Added menu entry + icon
* Tue Jun 19 2001 didge@suse.de
- Version 0.4.99claws
  Date 15.6.2001
* Tue Jun 12 2001 didge@suse.de
- Try to fix the CVS-version, to build it.
* Tue Jun  5 2001 didge@suse.de
- Version 0.4.99claws3
  Date 5.6.2001
* Sun May 13 2001 didge@suse.de
- Verison 0.4.66 + patches:
  add-sender-to-addressbook-1.patch
  empty_mailbox-2.patch
  foldercolor.patch
  font-sel.patch
  gtkstext.0.4.63.patch
  showaddr.patch
  sylpheed-0.4.63-marknav.patch
  sylpheed-0.4.65cvs8-unlimited_from.patch
  sylpheed-0.4.66-gpgpopup.patch
  sylpheed-0.4.66-gtkspell.patch
  sylpheed-0.4.66-no-retrieval-dialog
  sylpheed-0.4.66-nogpgwarn.patch
  sylpheed-autodelete-6.patch
  sylpheed-config-0.4.64.patch
  sylpheed-custom-headers-5.patch
  sylpheed-ldapaddressbook-v2.patch
* Tue May  8 2001 mfabian@suse.de
- bzip2 sources
* Tue Apr 24 2001 didge@suse.de
  Version 0.4.65cvs4.
  The following patches were applied :
- add-sender-to-addressbook.patch
- bytesread.patch
- empty_mailbox-2.patch
- foldercolor.patch
- font-sel.patch
- gtkstext.0.4.63.patch
- progresswindow.patch
- sylpheed-0.4.63-marknav.patch
- sylpheed-0.4.63-update_colors.patch
- sylpheed-0.4.63-warnqueued.patch
- sylpheed-0.4.64-gpgkeysel.patch
- sylpheed-autodelete-5.patch
- sylpheed-config-0.4.64.patch
- sylpheed-custom-headers-5.patch
- sylpheed-forward-3.patch
- sylpheed-news-3.patch
- sylpheed-open-url.patch
- activated IPv6 support
- activated GPGME support (needs GPGME to work)
* Fri Apr 20 2001 didge@suse.de
- activated IPv6 support
- activated GPGME support (needs GPGME to work)
* Fri Apr 20 2001 didge@suse.de
- Version 0.4.64
- Patches:
  add-sender-to-addressbook-1.patch
  foldercolor.patch
  font-sel.patch
  progresswindow.patch
  sylpheed-0.4.63-marknav.patch
  sylpheed-0.4.63-update_colors.patch
  sylpheed-0.4.63-warnqueued.patch
  sylpheed-0.4.63cvs9-layout2.patch
  sylpheed-0.4.63cvs9-noparts.patch
  sylpheed-0.4.63cvs9-showserver.patch
  sylpheed-0.4.64-gpgkeysel.patch
  sylpheed-custom-headers-4.patch
  sylpheed-forward-2.patch
  sylpheed-news-2.patch
  sylpheed-open-url.patch
  sylpheed-toolbar.patch
  usestrftime.patch
  bytesread.patch
* Tue Apr 10 2001 didge@suse.de
  Patches added:
- empty_mailbox.patch
- font-sel.patch
- gtkstext.patch
- patch-config-4.60.patch
- sylpheed-autodelete-4.patch
- sylpheed-forward-2.patch
- sylpheed-news-2.patch
- sylpheed-custom-headers-4.patch
- sylpheed-open-url.patch
* Tue Apr 10 2001 didge@suse.de
- version 0.4.63
- changes:
  * Some menu items are sorted out.
  * `Attract by subject' is speeded up.
  * Smooth scrolling of message text is enabled.
  * Generic mark and Deleted mark became permanent.
  * Replied and Forwarded mark are enabled.
  * The design of New and Unread mark is changed.
  * Generic mark and Unread mark can be toggled with clicking summary view.
  * Long References header is truncated now.
  * Updated the GnuPG support code.
  * Messages can be moved across file systems.
  * Message date is converted into local time when displaying.
  * The colors of quoted part and URI of messages can be specified,
    and they are specifiable according to quotation level.
  * It is enabled to keep the current folder after receiving new messages.
  * The speed of cache reading is improved.
  * Message copy is implemented.
  * Many other bugfixes have been done.
* Mon Mar 19 2001 didge@suse.de
- small bugfix to the patched version of 0.4.63cvs3
- sylpheed patched 9.1
* Mon Mar 19 2001 didge@suse.de
- new patched version of 0.4.63cvs3
* Wed Mar 14 2001 didge@suse.de
- build patched version 0.4.62
- add-sender-to-addressbook.patch
- sylpheed-open-url.patch
- empty_mailbox.patch
- patch-config-4.60.patch
- sylpheed-forward.patch
- sylpheed-custom-headers-3.patch
- sylpheed-autodelete-2.patch
* Mon Mar 12 2001 ro@suse.de
- fixed macro use in specfile
* Mon Mar 12 2001 didge@suse.de
- some new features are added, new version 0.4.62
* Tue Feb 13 2001 didge@suse.de
- a lot of bugfixes and two new versions, newest 0.4.61
* Tue Jan 30 2001 ro@suse.de
- changed neededforbuild <imlibcfe> to <imlib-config>
* Tue Jan 16 2001 didge@suse.de
- a lot of bugs where fixed and the news support was redesigned
- new version 0.4.52
* Wed Dec 27 2000 didge@suse.de
- some segfaults were fixed in the version 0.4.9
* Mon Dec 11 2000 didge@suse.de
- problems hopefully fixed :-)
* Mon Dec 11 2000 didge@suse.de
- updated to 0.4.8 and try fixed build problems
* Mon Dec  4 2000 didge@suse.de
- updated to 0.4.7 and updated %%description
* Mon Nov 20 2000 didge@suse.de
- first build of sylpheed (0.4.4)
